# Contributing
We welcome all contributions, whether questions, code or documentation. We will add sections about how to contribute in
in the near future.

## Documentation
We use [**MKDOCS**](https://www.mkdocs.org) as a documentation tool. Please create a PR if you have any additions or
contributions to make. All docs can be written in MD or html.
